==> zio-aws-location_2.12-5.17.130.6-sources.jar: zio/aws/location/model/ListGeofenceResponseEntry.scala <==
package zio.aws.location.model
import zio.ZIO
import zio.aws.core.BuilderHelper
import java.time.Instant
import zio.aws.location.model.primitives.{Id, Timestamp}
import scala.jdk.CollectionConverters._
final case class ListGeofenceResponseEntry(
    createTime: Timestamp,
    geofenceId: Id,
    geometry: zio.aws.location.model.GeofenceGeometry,
    status: String,
    updateTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry = {
    import ListGeofenceResponseEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
      .builder()
      .createTime(Timestamp.unwrap(createTime): Instant)
      .geofenceId(Id.unwrap(geofenceId): java.lang.String)
      .geometry(geometry.buildAwsValue())
      .status(status: java.lang.String)
      .updateTime(Timestamp.unwrap(updateTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly =
    zio.aws.location.model.ListGeofenceResponseEntry.wrap(buildAwsValue())
}
object ListGeofenceResponseEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.ListGeofenceResponseEntry =
      zio.aws.location.model.ListGeofenceResponseEntry(
        createTime,
        geofenceId,
        geometry.asEditable,
        status,
        updateTime
      )
    def createTime: Timestamp
    def geofenceId: Id
    def geometry: zio.aws.location.model.GeofenceGeometry.ReadOnly
    def status: String
    def updateTime: Timestamp
    def getCreateTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createTime)
    def getGeofenceId: ZIO[Any, Nothing, Id] = ZIO.succeed(geofenceId)
    def getGeometry
        : ZIO[Any, Nothing, zio.aws.location.model.GeofenceGeometry.ReadOnly] =
      ZIO.succeed(geometry)
    def getStatus: ZIO[Any, Nothing, String] = ZIO.succeed(status)
    def getUpdateTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(updateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ) extends zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly {
    override val createTime: Timestamp =
      zio.aws.location.model.primitives.Timestamp(impl.createTime())
    override val geofenceId: Id =
      zio.aws.location.model.primitives.Id(impl.geofenceId())
    override val geometry: zio.aws.location.model.GeofenceGeometry.ReadOnly =
      zio.aws.location.model.GeofenceGeometry.wrap(impl.geometry())
    override val status: String = impl.status(): String
    override val updateTime: Timestamp =
      zio.aws.location.model.primitives.Timestamp(impl.updateTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ): zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-location_2.12-6.20.97.2-sources.jar: zio/aws/location/model/ListGeofenceResponseEntry.scala <==
package zio.aws.location.model
import zio.aws.location.model.primitives.{
  PropertyMapValueString,
  PropertyMapKeyString,
  Id,
  Timestamp
}
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import scala.jdk.CollectionConverters._
final case class ListGeofenceResponseEntry(
    createTime: Timestamp,
    geofenceId: Id,
    geofenceProperties: Optional[
      Map[PropertyMapKeyString, PropertyMapValueString]
    ] = Optional.Absent,
    geometry: zio.aws.location.model.GeofenceGeometry,
    status: String,
    updateTime: Timestamp
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry = {
    import ListGeofenceResponseEntry.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
      .builder()
      .createTime(Timestamp.unwrap(createTime): Instant)
      .geofenceId(Id.unwrap(geofenceId): java.lang.String)
      .optionallyWith(
        geofenceProperties.map(value =>
          value
            .map({ case (key, value) =>
              (PropertyMapKeyString.unwrap(
                key
              ): java.lang.String) -> (PropertyMapValueString.unwrap(
                value
              ): java.lang.String)
            })
            .asJava
        )
      )(_.geofenceProperties)
      .geometry(geometry.buildAwsValue())
      .status(status: java.lang.String)
      .updateTime(Timestamp.unwrap(updateTime): Instant)
      .build()
  }
  def asReadOnly: zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly =
    zio.aws.location.model.ListGeofenceResponseEntry.wrap(buildAwsValue())
}
object ListGeofenceResponseEntry {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.location.model.ListGeofenceResponseEntry =
      zio.aws.location.model.ListGeofenceResponseEntry(
        createTime,
        geofenceId,
        geofenceProperties.map(value => value),
        geometry.asEditable,
        status,
        updateTime
      )
    def createTime: Timestamp
    def geofenceId: Id
    def geofenceProperties
        : Optional[Map[PropertyMapKeyString, PropertyMapValueString]]
    def geometry: zio.aws.location.model.GeofenceGeometry.ReadOnly
    def status: String
    def updateTime: Timestamp
    def getCreateTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(createTime)
    def getGeofenceId: ZIO[Any, Nothing, Id] = ZIO.succeed(geofenceId)
    def getGeofenceProperties: ZIO[Any, AwsError, Map[
      PropertyMapKeyString,
      PropertyMapValueString
    ]] = AwsError.unwrapOptionField("geofenceProperties", geofenceProperties)
    def getGeometry
        : ZIO[Any, Nothing, zio.aws.location.model.GeofenceGeometry.ReadOnly] =
      ZIO.succeed(geometry)
    def getStatus: ZIO[Any, Nothing, String] = ZIO.succeed(status)
    def getUpdateTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(updateTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ) extends zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly {
    override val createTime: Timestamp =
      zio.aws.location.model.primitives.Timestamp(impl.createTime())
    override val geofenceId: Id =
      zio.aws.location.model.primitives.Id(impl.geofenceId())
    override val geofenceProperties
        : Optional[Map[PropertyMapKeyString, PropertyMapValueString]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.geofenceProperties())
        .map(value =>
          value.asScala
            .map({ case (key, value) =>
              zio.aws.location.model.primitives
                .PropertyMapKeyString(key) -> zio.aws.location.model.primitives
                .PropertyMapValueString(value)
            })
            .toMap
        )
    override val geometry: zio.aws.location.model.GeofenceGeometry.ReadOnly =
      zio.aws.location.model.GeofenceGeometry.wrap(impl.geometry())
    override val status: String = impl.status(): String
    override val updateTime: Timestamp =
      zio.aws.location.model.primitives.Timestamp(impl.updateTime())
  }
  def wrap(
      impl: software.amazon.awssdk.services.location.model.ListGeofenceResponseEntry
  ): zio.aws.location.model.ListGeofenceResponseEntry.ReadOnly = new Wrapper(
    impl
  )
}
